from Products.Archetypes.public import *

try:
    from Products.ATContentTypes.content.file import ATFile, ATFileSchema
except ImportError:
    # For ATCT 0.2 compatibility
    from Products.ATContentTypes.types.ATFile import ATFile
    from Products.ATContentTypes.types.schemata import ATFileSchema
from Products.ATColorPickerWidget.ColorPickerWidget import ColorPickerWidget
try :
    from Products.CMFCore import permissions
except ImportError:
    # For CMF 1.4 compatibility
    from Products.CMFCore import CMFCorePermissions
    permissions = CMFCorePermissions
from Products.CMFCore.utils import getToolByName
from AccessControl import ClassSecurityInfo
from swfHeaderData import analyseContent
from config import *


schema = ATFileSchema + Schema((

    IntegerField('scale',
                 required = True,
                 searchable = False,
                 default = 100,
                 validators = ('isInt'),
                 vocabulary = SCALE_LIST,
                 widget=SelectionWidget(label = 'Scale',
                                        label_msgid ='label_scale',
                                        description = 'Scale of the flash movie.',
                                        description_msgid ="desc_scale",
                                        i18n_domain='ATFlashMovie'),
                 ),

    StringField('bgcolor',
                 required = True,
                 searchable = False,
                 default = '#FFFFFF',
                 widget=ColorPickerWidget(label = 'Background Color',
                                        label_msgid ='label_bgcolor',
                                        description = 'Select background color of the flash movie.',
                                        description_msgid ="desc_bgcolor",
                                        i18n_domain='ATFlashMovie'),
                 ),

    IntegerField('width',
                 required = False,
                 searchable = False,
                 validators = ('isInt'),
                 widget=IntegerWidget(label ='Width', modes= ('view',),
                                      label_msgid ='label_width',
                                      description = 'Width of flash movie.',
                                      description_msgid ="desc_width",
                                      i18n_domain='ATFlashMovie'),
                 ),
    
    IntegerField('height',
                 required = False,
                 searchable = False,
                 validators = ('isInt'),
                 widget=IntegerWidget(label ='Height', modes= ('view',),
                                      label_msgid ='label_height',
                                      description = 'Height of flash movie.',
                                      description_msgid ="desc_hight",
                                      i18n_domain='ATFlashMovie'),
                 ),

    StringField('flashversion',
                required = False,
                searchable = False,
                widget=StringWidget(modes= ('view',),
                                    label ='Flash Version',
                                    label_msgid ='label_flashversion',
                                    i18n_domain='ATFlashMovie'),
                ),
    ))


class ATFlashMovie(ATFile):
    """A Macromedia flash film"""
    
    schema = schema
    archetype_name = 'Flash Movie'
    meta_type = 'FlashMovie'
    portal_type = 'FlashMovie'
    content_icon = 'flashmovie_icon.gif'
    immediate_view = 'flashmovie_view'
    default_view   = 'flashmovie_view'
    suppl_views    = ()
    typeDescription= "A Macromedia flash film"
    typeDescMsgId  = 'description_edit_flash_file'
    assocFileExt   = ('swf',)
    
    global_allow = True

    security = ClassSecurityInfo()

    security.declareProtected(permissions.ModifyPortalContent, 'setFile')
    def setFile(self, value, **kwargs):
        """Saves file and stores flash informations (size, flash version)"""
        ATFile.setFile(self, value, **kwargs)

        if value:
            value.seek(0) # rewind
            tags = analyseContent(value.read(1024))
            self.setWidth(tags['width'])
            self.setHeight(tags['height'])
            self.setFlashversion(tags['flashversion'])

    def getDisplayHeight(self):
        """Returns height in pixels for selected scale"""
        if self.height:
            return int(self.height * (self.getScale() / 100.0))
        else:
            return None
    
    def getDisplayWidth(self):
        """Returns width in pixels for selected scale"""
        if self.width:
            return int(self.width * (self.getScale() / 100.0))
        else:
            return None

    security.declarePublic('getIcon')
    def getIcon(self, relative_to_portal=0):
        """Returns icon for flash movies"""
        icon = self.content_icon

        if relative_to_portal:
            return icon
        else:
            utool = getToolByName( self, 'portal_url' )
            # Relative to REQUEST['BASEPATH1']
            res = utool(relative=1) + '/' + icon
            while res[:1] == '/':
                res = res[1:]
            return res

registerType(ATFlashMovie)
